type Runtime = {
    args: Array<string>;
    positionals: Array<string>;
};

type CommonTypes = StringConstructor | NumberConstructor | BooleanConstructor;

declare class StacklessError extends Error {
    constructor(message: string);
    format(...param: Array<any>): StacklessError;
}

declare const getJsonFile: <T extends any[] | Record<string, any>>(path: string, reviver?: ((this: any, key: string, value: any) => any) | undefined) => T;

type Package = {
    name: string;
    version: string;
    bin?: Record<string, string>;
};
declare const getPackageJson: (root?: string) => Package;

declare const getProgramArguments: () => string[];

type RuntimeOperator = {
    args: Array<string>;
    positionals: Array<string>;
};
declare const runtime: (positionals?: Array<string>, args?: Array<string>) => RuntimeOperator;

type VersionOperator = {
    version: string;
};
declare const version: (version: string) => VersionOperator;

type ExtractParamName<T extends ParamOperator> = `${T extends ParamOperator<infer N> ? N : never}`;
type DefaultParam<T extends CommonTypes> = T extends NumberConstructor ? number : T extends StringConstructor ? string : T extends BooleanConstructor ? boolean : string;
type ParamsWithPositional<Params extends ParamOperator, Positional extends string, PositionalType extends CommonTypes> = Params | ParamOperator<Positional, PositionalType>;
type ExtractParamType<Param> = Param extends ParamOperator<string, infer Type> ? DefaultParam<Type> : never;
type ExtractParams<Name extends string, Params extends ParamOperator, PositionalType extends CommonTypes> = Name extends `${string} <${infer Positional}>` ? {
    [Param in ParamsWithPositional<Params, Positional, PositionalType> as ExtractParamName<Param>]: ExtractParamType<Param>;
} : {
    [Param in Params as ExtractParamName<Param>]: ExtractParamType<Param>;
};
type ParamOptions<Type extends CommonTypes> = {
    type?: Type;
    short?: string;
    multiple?: boolean;
    default?: DefaultParam<Type>;
    description?: string;
};
type ParamOperator<Name extends string = string, Type extends CommonTypes = CommonTypes> = {
    param: Name;
    options?: ParamOptions<Type>;
};
declare const param: <Name extends string, Type extends CommonTypes = BooleanConstructor>(name: Name, options?: ParamOptions<Type> | undefined) => ParamOperator<Name, Type>;

type CommandOptions<Name extends string, Params extends ParamOperator, PositionalType extends CommonTypes> = {
    params?: ReadonlyArray<Params>;
    short?: string;
    description?: string;
    positional?: PositionalType;
    next: (params: ExtractParams<Name, Params, PositionalType>) => void | Promise<void>;
};
type CommandOperator<Name extends string, Params extends ParamOperator, PositionalType extends CommonTypes> = {
    command: Name;
    options: CommandOptions<Name, Params, PositionalType>;
};
declare const command: <Name extends string, Params extends ParamOperator, PositionalType extends CommonTypes = StringConstructor>(name: Name, options: CommandOptions<Name, Params, PositionalType>) => CommandOperator<string, ParamOperator, CommonTypes>;

type CommandsOperator = {
    commands: Array<CommandOperator<string, ParamOperator, CommonTypes>>;
};
declare const commands: (commands: Array<CommandOperator<string, ParamOperator, CommonTypes>>) => CommandsOperator;

type ProgramOperator = VersionOperator | UsageOperator | CommandsOperator | CatchErrorOperator | RuntimeOperator;
type ProgramResult = {
    error: Error | null;
};

declare const matchCommandName: (operator: CommandOperator<string, ParamOperator, CommonTypes>, input: string) => boolean;
declare const getCommandPositional: (runtime: Runtime, operator: CommandOperator<string, ParamOperator, CommonTypes>) => {
    [x: string]: string;
} | undefined;
declare const printErrorWithStack: (error: Error) => boolean;
declare const printHelp: (operators: Array<ProgramOperator>) => void;
declare const catchErrorWithResult: (operators: Array<ProgramOperator>, result: ProgramResult) => ProgramResult;

declare const options: <Operators extends ParamOperator>(operators: readonly Operators[]) => readonly Operators[];

declare const program: (operators: Array<ProgramOperator>) => Promise<ProgramResult>;

type CatchErrorHandler = (error: Error, operators: Array<ProgramOperator>) => void;
type CatchErrorOperator = {
    catchError: CatchErrorHandler;
};
declare const catchError: (handle: (error: Error, operators: Array<any>) => void) => CatchErrorOperator;

type UsageOperator = {
    usage: string;
};
declare const usage: (name: string) => UsageOperator;

declare const getProgramParams: (runtime: Runtime, operators: ReadonlyArray<ParamOperator>) => Record<string, DefaultParam<CommonTypes>>;

declare const getProgramPositionals: () => string[];

declare const toNumber: (value: any) => Array<number> | number | undefined;

declare const toString: (value: any) => Array<string> | string | undefined;

declare const isCommandOperator: <Name extends string, Params extends ParamOperator, Positional extends CommonTypes>(operator: any) => operator is CommandOperator<Name, Params, Positional>;
declare const isCatchErrorOperator: (value: any) => value is CatchErrorOperator;
declare const isCommandsOperator: (operator: any) => operator is CommandsOperator;
declare const isParamOperator: <Name extends string, Type extends CommonTypes>(value: any) => value is ParamOperator<Name, Type>;
declare const isRuntimeOperator: (value: any) => value is RuntimeOperator;
declare const isUsageOperator: (value: any) => value is UsageOperator;
declare const isVersionOperator: (operator: any) => operator is VersionOperator;

export { type CatchErrorHandler, type CatchErrorOperator, type CommandOperator, type CommandOptions, type CommandsOperator, type CommonTypes, type DefaultParam, type ExtractParamName, type ExtractParams, type ParamOperator, type ParamOptions, type ProgramOperator, type ProgramResult, type Runtime, type RuntimeOperator, StacklessError, type UsageOperator, type VersionOperator, catchError, catchErrorWithResult, command, commands, getCommandPositional, getJsonFile, getPackageJson, getProgramArguments, getProgramParams, getProgramPositionals, isCatchErrorOperator, isCommandOperator, isCommandsOperator, isParamOperator, isRuntimeOperator, isUsageOperator, isVersionOperator, matchCommandName, options, param, printErrorWithStack, printHelp, program, runtime, toNumber, toString, usage, version };
