// lib/common/stackless-error.ts
import { format } from "node:util";
var StacklessError = class _StacklessError extends Error {
  constructor(message) {
    super(message);
    this.stack = void 0;
  }
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  format(...param2) {
    const formattedMessage = format(this.message, ...param2);
    return new _StacklessError(formattedMessage);
  }
};

// lib/utils/get-json-file.ts
import { existsSync, readFileSync } from "node:fs";
import { isAbsolute, join } from "node:path";
var getJsonFile = (path, reviver) => {
  const filename = isAbsolute(path) ? path : join(process.cwd(), path);
  if (!existsSync(filename)) {
    throw new Error(`Yaml file does not exists: ${filename}`);
  }
  const buffer = readFileSync(filename, {
    encoding: "utf-8"
  });
  return JSON.parse(buffer, reviver);
};

// lib/utils/get-package-json.ts
import { join as join2 } from "node:path";
var getPackageJson = (root) => getJsonFile(root ? join2(root, "package.json") : "package.json");

// lib/utils/get-program-arguments.ts
var getProgramArguments = () => process.argv.slice(2);

// lib/utils/get-program-params.ts
import { parseArgs } from "node:util";
import { isNil as isNil3, reject } from "ramda";

// lib/utils/get-param-default-value.ts
import { isNotNil } from "ramda";
var getParamDefaultValue = (options2) => {
  const type = options2.type ?? Boolean;
  const isMultiple = options2.multiple ?? false;
  if (isNotNil(options2.default)) {
    return options2.default;
  }
  if (isMultiple) {
    return options2.default || [];
  }
  if (type === Boolean) {
    return false;
  }
  return void 0;
};

// lib/utils/to-string.ts
import { isNil } from "ramda";
var toString = (value) => {
  if (isNil(value)) {
    return void 0;
  }
  if (Array.isArray(value)) {
    return value.map((v) => String(v));
  }
  return String(value);
};

// lib/utils/to-number.ts
import { isNil as isNil2 } from "ramda";
var toNumber = (value) => {
  if (isNil2(value)) {
    return void 0;
  }
  if (Array.isArray(value)) {
    return value.map((v) => Number(v));
  }
  return Number(value);
};

// lib/utils/get-program-params.ts
var getProgramParams = (runtime2, operators) => {
  const options2 = operators.reduce((result, { param: param2, options: paramOptions }) => {
    const { type, multiple, short } = paramOptions || {
      type: Boolean
    };
    const schema = {
      [param2]: {
        type: !type || type === Boolean ? "boolean" : "string",
        ...reject(isNil3, {
          multiple,
          short
        })
      }
    };
    return {
      ...result,
      ...schema
    };
  }, {});
  try {
    const { values } = parseArgs({
      strict: true,
      allowPositionals: true,
      args: runtime2.args,
      options: options2
    });
    return operators.reduce((result, { param: param2, options: options3 = {} }) => {
      const value = values[param2];
      const type = options3.type || Boolean;
      const valueOrDefault = isNil3(value) ? getParamDefaultValue(options3) : value;
      switch (type) {
        case String: {
          return {
            ...result,
            [param2]: toString(valueOrDefault)
          };
        }
        case Number: {
          return {
            ...result,
            [param2]: toNumber(valueOrDefault)
          };
        }
        default: {
          return {
            ...result,
            [param2]: valueOrDefault
          };
        }
      }
    }, {});
  } catch (error) {
    if (!(error instanceof Error)) {
      throw new StacklessError(`UNDEFINED_BEHAVIOR: ${error}`);
    }
    const match = error.message.match(/'([^']*)'/);
    if (!match) {
      throw new StacklessError(`UNDEFINED_BEHAVIOR: ${error.message}`);
    }
    throw new StacklessError(`UNKNOWN_OPTION: ${match.at(1)}`);
  }
};

// lib/utils/get-program-positionals.ts
import { parseArgs as parseArgs2 } from "node:util";
var getProgramPositionals = () => {
  const { positionals } = parseArgs2({
    strict: false,
    allowPositionals: true,
    args: process.argv.slice(2)
  });
  return positionals;
};

// lib/utils/operators.ts
import { has, is } from "ramda";
var isCommandOperator = (operator) => is(Object, operator) && has("command", operator);
var isCatchErrorOperator = (value) => is(Object, value) && has("catchError", value);
var isCommandsOperator = (operator) => is(Object, operator) && has("commands", operator);
var isParamOperator = (value) => is(Object, value) && has("param", value);
var isRuntimeOperator = (value) => is(Object, value) && has("args", value) && has("positionals", value);
var isUsageOperator = (value) => is(Object, value) && has("usage", value);
var isVersionOperator = (operator) => is(Object, operator) && has("version", operator);

// lib/operators/runtime.ts
var runtime = (positionals, args) => ({
  args: args || getProgramArguments(),
  positionals: positionals || getProgramPositionals()
});

// lib/operators/version.ts
var version = (version2) => ({
  version: version2
});

// lib/operators/param.ts
var param = (name, options2) => ({
  param: name,
  options: options2
});

// lib/operators/command.ts
var command = (name, options2) => ({
  command: name,
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  options: options2
});

// lib/operators/commands.ts
var commands = (commands2) => ({
  commands: commands2
});

// lib/operators/catch-error.ts
var catchError = (handle) => ({
  catchError: handle
});

// lib/operators/usage.ts
var usage = (name) => ({
  usage: name
});

// node_modules/chalk/source/vendor/ansi-styles/index.js
var ANSI_BACKGROUND_OFFSET = 10;
var wrapAnsi16 = (offset = 0) => (code) => `\x1B[${code + offset}m`;
var wrapAnsi256 = (offset = 0) => (code) => `\x1B[${38 + offset};5;${code}m`;
var wrapAnsi16m = (offset = 0) => (red, green, blue) => `\x1B[${38 + offset};2;${red};${green};${blue}m`;
var styles = {
  modifier: {
    reset: [0, 0],
    // 21 isn't widely supported and 22 does the same thing
    bold: [1, 22],
    dim: [2, 22],
    italic: [3, 23],
    underline: [4, 24],
    overline: [53, 55],
    inverse: [7, 27],
    hidden: [8, 28],
    strikethrough: [9, 29]
  },
  color: {
    black: [30, 39],
    red: [31, 39],
    green: [32, 39],
    yellow: [33, 39],
    blue: [34, 39],
    magenta: [35, 39],
    cyan: [36, 39],
    white: [37, 39],
    // Bright color
    blackBright: [90, 39],
    gray: [90, 39],
    // Alias of `blackBright`
    grey: [90, 39],
    // Alias of `blackBright`
    redBright: [91, 39],
    greenBright: [92, 39],
    yellowBright: [93, 39],
    blueBright: [94, 39],
    magentaBright: [95, 39],
    cyanBright: [96, 39],
    whiteBright: [97, 39]
  },
  bgColor: {
    bgBlack: [40, 49],
    bgRed: [41, 49],
    bgGreen: [42, 49],
    bgYellow: [43, 49],
    bgBlue: [44, 49],
    bgMagenta: [45, 49],
    bgCyan: [46, 49],
    bgWhite: [47, 49],
    // Bright color
    bgBlackBright: [100, 49],
    bgGray: [100, 49],
    // Alias of `bgBlackBright`
    bgGrey: [100, 49],
    // Alias of `bgBlackBright`
    bgRedBright: [101, 49],
    bgGreenBright: [102, 49],
    bgYellowBright: [103, 49],
    bgBlueBright: [104, 49],
    bgMagentaBright: [105, 49],
    bgCyanBright: [106, 49],
    bgWhiteBright: [107, 49]
  }
};
var modifierNames = Object.keys(styles.modifier);
var foregroundColorNames = Object.keys(styles.color);
var backgroundColorNames = Object.keys(styles.bgColor);
var colorNames = [...foregroundColorNames, ...backgroundColorNames];
function assembleStyles() {
  const codes = /* @__PURE__ */ new Map();
  for (const [groupName, group] of Object.entries(styles)) {
    for (const [styleName, style] of Object.entries(group)) {
      styles[styleName] = {
        open: `\x1B[${style[0]}m`,
        close: `\x1B[${style[1]}m`
      };
      group[styleName] = styles[styleName];
      codes.set(style[0], style[1]);
    }
    Object.defineProperty(styles, groupName, {
      value: group,
      enumerable: false
    });
  }
  Object.defineProperty(styles, "codes", {
    value: codes,
    enumerable: false
  });
  styles.color.close = "\x1B[39m";
  styles.bgColor.close = "\x1B[49m";
  styles.color.ansi = wrapAnsi16();
  styles.color.ansi256 = wrapAnsi256();
  styles.color.ansi16m = wrapAnsi16m();
  styles.bgColor.ansi = wrapAnsi16(ANSI_BACKGROUND_OFFSET);
  styles.bgColor.ansi256 = wrapAnsi256(ANSI_BACKGROUND_OFFSET);
  styles.bgColor.ansi16m = wrapAnsi16m(ANSI_BACKGROUND_OFFSET);
  Object.defineProperties(styles, {
    rgbToAnsi256: {
      value(red, green, blue) {
        if (red === green && green === blue) {
          if (red < 8) {
            return 16;
          }
          if (red > 248) {
            return 231;
          }
          return Math.round((red - 8) / 247 * 24) + 232;
        }
        return 16 + 36 * Math.round(red / 255 * 5) + 6 * Math.round(green / 255 * 5) + Math.round(blue / 255 * 5);
      },
      enumerable: false
    },
    hexToRgb: {
      value(hex) {
        const matches = /[a-f\d]{6}|[a-f\d]{3}/i.exec(hex.toString(16));
        if (!matches) {
          return [0, 0, 0];
        }
        let [colorString] = matches;
        if (colorString.length === 3) {
          colorString = [...colorString].map((character) => character + character).join("");
        }
        const integer = Number.parseInt(colorString, 16);
        return [
          /* eslint-disable no-bitwise */
          integer >> 16 & 255,
          integer >> 8 & 255,
          integer & 255
          /* eslint-enable no-bitwise */
        ];
      },
      enumerable: false
    },
    hexToAnsi256: {
      value: (hex) => styles.rgbToAnsi256(...styles.hexToRgb(hex)),
      enumerable: false
    },
    ansi256ToAnsi: {
      value(code) {
        if (code < 8) {
          return 30 + code;
        }
        if (code < 16) {
          return 90 + (code - 8);
        }
        let red;
        let green;
        let blue;
        if (code >= 232) {
          red = ((code - 232) * 10 + 8) / 255;
          green = red;
          blue = red;
        } else {
          code -= 16;
          const remainder = code % 36;
          red = Math.floor(code / 36) / 5;
          green = Math.floor(remainder / 6) / 5;
          blue = remainder % 6 / 5;
        }
        const value = Math.max(red, green, blue) * 2;
        if (value === 0) {
          return 30;
        }
        let result = 30 + (Math.round(blue) << 2 | Math.round(green) << 1 | Math.round(red));
        if (value === 2) {
          result += 60;
        }
        return result;
      },
      enumerable: false
    },
    rgbToAnsi: {
      value: (red, green, blue) => styles.ansi256ToAnsi(styles.rgbToAnsi256(red, green, blue)),
      enumerable: false
    },
    hexToAnsi: {
      value: (hex) => styles.ansi256ToAnsi(styles.hexToAnsi256(hex)),
      enumerable: false
    }
  });
  return styles;
}
var ansiStyles = assembleStyles();
var ansi_styles_default = ansiStyles;

// node_modules/chalk/source/vendor/supports-color/index.js
import process2 from "node:process";
import os from "node:os";
import tty from "node:tty";
function hasFlag(flag, argv = globalThis.Deno ? globalThis.Deno.args : process2.argv) {
  const prefix = flag.startsWith("-") ? "" : flag.length === 1 ? "-" : "--";
  const position = argv.indexOf(prefix + flag);
  const terminatorPosition = argv.indexOf("--");
  return position !== -1 && (terminatorPosition === -1 || position < terminatorPosition);
}
var { env } = process2;
var flagForceColor;
if (hasFlag("no-color") || hasFlag("no-colors") || hasFlag("color=false") || hasFlag("color=never")) {
  flagForceColor = 0;
} else if (hasFlag("color") || hasFlag("colors") || hasFlag("color=true") || hasFlag("color=always")) {
  flagForceColor = 1;
}
function envForceColor() {
  if ("FORCE_COLOR" in env) {
    if (env.FORCE_COLOR === "true") {
      return 1;
    }
    if (env.FORCE_COLOR === "false") {
      return 0;
    }
    return env.FORCE_COLOR.length === 0 ? 1 : Math.min(Number.parseInt(env.FORCE_COLOR, 10), 3);
  }
}
function translateLevel(level) {
  if (level === 0) {
    return false;
  }
  return {
    level,
    hasBasic: true,
    has256: level >= 2,
    has16m: level >= 3
  };
}
function _supportsColor(haveStream, { streamIsTTY, sniffFlags = true } = {}) {
  const noFlagForceColor = envForceColor();
  if (noFlagForceColor !== void 0) {
    flagForceColor = noFlagForceColor;
  }
  const forceColor = sniffFlags ? flagForceColor : noFlagForceColor;
  if (forceColor === 0) {
    return 0;
  }
  if (sniffFlags) {
    if (hasFlag("color=16m") || hasFlag("color=full") || hasFlag("color=truecolor")) {
      return 3;
    }
    if (hasFlag("color=256")) {
      return 2;
    }
  }
  if ("TF_BUILD" in env && "AGENT_NAME" in env) {
    return 1;
  }
  if (haveStream && !streamIsTTY && forceColor === void 0) {
    return 0;
  }
  const min = forceColor || 0;
  if (env.TERM === "dumb") {
    return min;
  }
  if (process2.platform === "win32") {
    const osRelease = os.release().split(".");
    if (Number(osRelease[0]) >= 10 && Number(osRelease[2]) >= 10586) {
      return Number(osRelease[2]) >= 14931 ? 3 : 2;
    }
    return 1;
  }
  if ("CI" in env) {
    if ("GITHUB_ACTIONS" in env || "GITEA_ACTIONS" in env) {
      return 3;
    }
    if (["TRAVIS", "CIRCLECI", "APPVEYOR", "GITLAB_CI", "BUILDKITE", "DRONE"].some((sign) => sign in env) || env.CI_NAME === "codeship") {
      return 1;
    }
    return min;
  }
  if ("TEAMCITY_VERSION" in env) {
    return /^(9\.(0*[1-9]\d*)\.|\d{2,}\.)/.test(env.TEAMCITY_VERSION) ? 1 : 0;
  }
  if (env.COLORTERM === "truecolor") {
    return 3;
  }
  if (env.TERM === "xterm-kitty") {
    return 3;
  }
  if ("TERM_PROGRAM" in env) {
    const version2 = Number.parseInt((env.TERM_PROGRAM_VERSION || "").split(".")[0], 10);
    switch (env.TERM_PROGRAM) {
      case "iTerm.app": {
        return version2 >= 3 ? 3 : 2;
      }
      case "Apple_Terminal": {
        return 2;
      }
    }
  }
  if (/-256(color)?$/i.test(env.TERM)) {
    return 2;
  }
  if (/^screen|^xterm|^vt100|^vt220|^rxvt|color|ansi|cygwin|linux/i.test(env.TERM)) {
    return 1;
  }
  if ("COLORTERM" in env) {
    return 1;
  }
  return min;
}
function createSupportsColor(stream, options2 = {}) {
  const level = _supportsColor(stream, {
    streamIsTTY: stream && stream.isTTY,
    ...options2
  });
  return translateLevel(level);
}
var supportsColor = {
  stdout: createSupportsColor({ isTTY: tty.isatty(1) }),
  stderr: createSupportsColor({ isTTY: tty.isatty(2) })
};
var supports_color_default = supportsColor;

// node_modules/chalk/source/utilities.js
function stringReplaceAll(string, substring, replacer) {
  let index = string.indexOf(substring);
  if (index === -1) {
    return string;
  }
  const substringLength = substring.length;
  let endIndex = 0;
  let returnValue = "";
  do {
    returnValue += string.slice(endIndex, index) + substring + replacer;
    endIndex = index + substringLength;
    index = string.indexOf(substring, endIndex);
  } while (index !== -1);
  returnValue += string.slice(endIndex);
  return returnValue;
}
function stringEncaseCRLFWithFirstIndex(string, prefix, postfix, index) {
  let endIndex = 0;
  let returnValue = "";
  do {
    const gotCR = string[index - 1] === "\r";
    returnValue += string.slice(endIndex, gotCR ? index - 1 : index) + prefix + (gotCR ? "\r\n" : "\n") + postfix;
    endIndex = index + 1;
    index = string.indexOf("\n", endIndex);
  } while (index !== -1);
  returnValue += string.slice(endIndex);
  return returnValue;
}

// node_modules/chalk/source/index.js
var { stdout: stdoutColor, stderr: stderrColor } = supports_color_default;
var GENERATOR = Symbol("GENERATOR");
var STYLER = Symbol("STYLER");
var IS_EMPTY = Symbol("IS_EMPTY");
var levelMapping = [
  "ansi",
  "ansi",
  "ansi256",
  "ansi16m"
];
var styles2 = /* @__PURE__ */ Object.create(null);
var applyOptions = (object, options2 = {}) => {
  if (options2.level && !(Number.isInteger(options2.level) && options2.level >= 0 && options2.level <= 3)) {
    throw new Error("The `level` option should be an integer from 0 to 3");
  }
  const colorLevel = stdoutColor ? stdoutColor.level : 0;
  object.level = options2.level === void 0 ? colorLevel : options2.level;
};
var chalkFactory = (options2) => {
  const chalk2 = (...strings) => strings.join(" ");
  applyOptions(chalk2, options2);
  Object.setPrototypeOf(chalk2, createChalk.prototype);
  return chalk2;
};
function createChalk(options2) {
  return chalkFactory(options2);
}
Object.setPrototypeOf(createChalk.prototype, Function.prototype);
for (const [styleName, style] of Object.entries(ansi_styles_default)) {
  styles2[styleName] = {
    get() {
      const builder = createBuilder(this, createStyler(style.open, style.close, this[STYLER]), this[IS_EMPTY]);
      Object.defineProperty(this, styleName, { value: builder });
      return builder;
    }
  };
}
styles2.visible = {
  get() {
    const builder = createBuilder(this, this[STYLER], true);
    Object.defineProperty(this, "visible", { value: builder });
    return builder;
  }
};
var getModelAnsi = (model, level, type, ...arguments_) => {
  if (model === "rgb") {
    if (level === "ansi16m") {
      return ansi_styles_default[type].ansi16m(...arguments_);
    }
    if (level === "ansi256") {
      return ansi_styles_default[type].ansi256(ansi_styles_default.rgbToAnsi256(...arguments_));
    }
    return ansi_styles_default[type].ansi(ansi_styles_default.rgbToAnsi(...arguments_));
  }
  if (model === "hex") {
    return getModelAnsi("rgb", level, type, ...ansi_styles_default.hexToRgb(...arguments_));
  }
  return ansi_styles_default[type][model](...arguments_);
};
var usedModels = ["rgb", "hex", "ansi256"];
for (const model of usedModels) {
  styles2[model] = {
    get() {
      const { level } = this;
      return function(...arguments_) {
        const styler = createStyler(getModelAnsi(model, levelMapping[level], "color", ...arguments_), ansi_styles_default.color.close, this[STYLER]);
        return createBuilder(this, styler, this[IS_EMPTY]);
      };
    }
  };
  const bgModel = "bg" + model[0].toUpperCase() + model.slice(1);
  styles2[bgModel] = {
    get() {
      const { level } = this;
      return function(...arguments_) {
        const styler = createStyler(getModelAnsi(model, levelMapping[level], "bgColor", ...arguments_), ansi_styles_default.bgColor.close, this[STYLER]);
        return createBuilder(this, styler, this[IS_EMPTY]);
      };
    }
  };
}
var proto = Object.defineProperties(() => {
}, {
  ...styles2,
  level: {
    enumerable: true,
    get() {
      return this[GENERATOR].level;
    },
    set(level) {
      this[GENERATOR].level = level;
    }
  }
});
var createStyler = (open, close, parent) => {
  let openAll;
  let closeAll;
  if (parent === void 0) {
    openAll = open;
    closeAll = close;
  } else {
    openAll = parent.openAll + open;
    closeAll = close + parent.closeAll;
  }
  return {
    open,
    close,
    openAll,
    closeAll,
    parent
  };
};
var createBuilder = (self, _styler, _isEmpty) => {
  const builder = (...arguments_) => applyStyle(builder, arguments_.length === 1 ? "" + arguments_[0] : arguments_.join(" "));
  Object.setPrototypeOf(builder, proto);
  builder[GENERATOR] = self;
  builder[STYLER] = _styler;
  builder[IS_EMPTY] = _isEmpty;
  return builder;
};
var applyStyle = (self, string) => {
  if (self.level <= 0 || !string) {
    return self[IS_EMPTY] ? "" : string;
  }
  let styler = self[STYLER];
  if (styler === void 0) {
    return string;
  }
  const { openAll, closeAll } = styler;
  if (string.includes("\x1B")) {
    while (styler !== void 0) {
      string = stringReplaceAll(string, styler.close, styler.open);
      styler = styler.parent;
    }
  }
  const lfIndex = string.indexOf("\n");
  if (lfIndex !== -1) {
    string = stringEncaseCRLFWithFirstIndex(string, closeAll, openAll, lfIndex);
  }
  return openAll + string + closeAll;
};
Object.defineProperties(createChalk.prototype, styles2);
var chalk = createChalk();
var chalkStderr = createChalk({ level: stderrColor ? stderrColor.level : 0 });
var source_default = chalk;

// lib/actions/utils.ts
import stringLength from "string-length";
var matchCommandName = (operator, input) => {
  const [command2] = operator.command.split(/\s+/);
  if (!command2) {
    throw new Error(`Invalid operator command: ${operator.command}`);
  }
  return input === command2 || input === operator.options.short;
};
var getCommandPositional = (runtime2, operator) => {
  const match = operator.command.match(/<(.*)>/);
  if (!match) {
    return;
  }
  const name = match.at(1);
  const [value] = runtime2.positionals.splice(0, 1);
  if (!value) {
    throw new StacklessError(`MISSING_REQUIRED_COMMAND_POSITIONAL: ${name}`);
  }
  return { [name]: value };
};
var column = (text, size) => {
  const length = stringLength(text);
  const padding = Math.max(size - length, 0);
  return `${text}${Array(padding).fill(" ").join("")}`;
};
var printErrorWithStack = (error) => {
  console.log(`${source_default.bgRed(` ERROR `)} ${error.message}`);
  if (error instanceof StacklessError) {
    return false;
  }
  const { stack = "" } = error;
  const formattedErrorStack = stack.split(/\r\n|\r|\n/).slice(1).map((line) => ` ${line.trim()}`).join("\r\n");
  console.error(source_default.gray(formattedErrorStack));
  return true;
};
var printHelp = (operators) => {
  const { version: version2 } = operators.find(isVersionOperator) || {
    version: getPackageJson().version
  };
  console.log();
  console.log(column(source_default.green("version"), 8), version2);
  const { usage: usage2 } = operators.find(isUsageOperator) || {
    usage: `node ${process.argv.at(1) || "<unknown>"}`
  };
  console.log(column(source_default.green("usage"), 8), usage2, source_default.blue("<positional>"), source_default.gray("[options]"));
  console.log();
  const commandsOperators = operators.filter(isCommandsOperator);
  const commandOperators = commandsOperators.map(({ commands: commands2 }) => commands2).flat();
  const longestCommandName = commandOperators.map(({ command: command2 }) => command2.split(/\s+/)).reduce((acc, [name]) => Math.max(acc, name.length), 0);
  const longestCommandShortName = commandOperators.map(({ options: options2 }) => options2.short || "").reduce((acc, short) => Math.max(acc, short.length), 0);
  const formattedCommandOperators = !commandOperators.length ? ["<no registered commands>"] : commandOperators.map(({ command: command2, options: options2 }) => {
    const [name, positional] = command2.split(/\s+/);
    const short = options2.short ?? "";
    return `${column(name, longestCommandName + 2)} ${column(source_default.grey(short), longestCommandShortName + 2)} ${column(source_default.blue(positional || ""), 20)} ${source_default.gray(options2.description)}`;
  });
  console.log(`${source_default.green("commands")}`);
  console.log(formattedCommandOperators.join("\r\n"));
};
var catchErrorWithResult = (operators, result) => {
  const { error } = result;
  if (!error) {
    return result;
  }
  const [catchErrorOperator] = operators.filter(isCatchErrorOperator);
  if (catchErrorOperator) {
    catchErrorOperator.catchError(error, operators);
    return result;
  }
  if (!printErrorWithStack(error)) {
    printHelp(operators);
  }
  return result;
};

// lib/actions/options.ts
var options = (operators) => operators;

// lib/actions/program.ts
var program = async (operators) => {
  const runtime2 = operators.filter(isRuntimeOperator).at(0) || {
    args: getProgramArguments(),
    positionals: getProgramPositionals()
  };
  if (runtime2.args.includes("--help") || runtime2.args.includes("-h")) {
    printHelp(operators);
    return { error: null };
  }
  const [input] = runtime2.positionals.splice(0, 1);
  if (!input) {
    return catchErrorWithResult(operators, {
      error: new StacklessError("POSITIONAL_NOT_PROVIDED")
    });
  }
  const { commands: commands2 } = operators.find(isCommandsOperator) || {
    commands: []
  };
  const commandOperator = commands2.find((operator) => isCommandOperator(operator) && matchCommandName(operator, input));
  if (!commandOperator) {
    return catchErrorWithResult(operators, {
      error: new StacklessError(`COMMAND_NOT_FOUND: ${input}`)
    });
  }
  try {
    const positional = getCommandPositional(runtime2, commandOperator);
    const params = getProgramParams(runtime2, commandOperator.options.params || []);
    await commandOperator.options.next({
      ...positional,
      ...params
    });
    return { error: null };
  } catch (error) {
    return error instanceof Error ? catchErrorWithResult(operators, { error }) : catchErrorWithResult(operators, {
      error: new StacklessError(`UNDEFINED_BEHAVIOR: ${error}`)
    });
  }
};
export {
  StacklessError,
  catchError,
  catchErrorWithResult,
  command,
  commands,
  getCommandPositional,
  getJsonFile,
  getPackageJson,
  getProgramArguments,
  getProgramParams,
  getProgramPositionals,
  isCatchErrorOperator,
  isCommandOperator,
  isCommandsOperator,
  isParamOperator,
  isRuntimeOperator,
  isUsageOperator,
  isVersionOperator,
  matchCommandName,
  options,
  param,
  printErrorWithStack,
  printHelp,
  program,
  runtime,
  toNumber,
  toString,
  usage,
  version
};
